@@ -32,8 +32,4 @@ TEST_CASE("hoshen_kopelman_2d", "hoshen_kopelman")
   }
 }
 
-int main(int argc, char **argv)
-{
-  Catch::Session session;
-  return session.run(argc, argv);
-}
+#include "main.hh"
