@@ -2,6 +2,7 @@
 #include "catch.hh"
 #include <ftk/numeric/quadratic_interpolation.hh>
 #include <ftk/numeric/rand.hh>
+#include <ftk/external/diy/mpi.hpp>
 
 const int nruns = 1; // 00000;
 const double epsilon = 1e-9;
@@ -27,8 +28,4 @@ TEST_CASE("quadratic_interpolation") {
   }
 }
 
-int main(int argc, char **argv)
-{
-  Catch::Session session;
-  return session.run(argc, argv);
-}
+#include "main.hh"
